library(loadeR)
library(transformeR)
library(ggplot2)
library(RColorBrewer)
library(maps)

rm(list=ls()) ; graphics.off() ; gc()

#Directory information
setwd("~/Documents/ETCCDI_eobs/")
OUTPUTS <- "OUTPUTS/"

#Useful information
ETCCDI_index <- c("Rx1day","Rx5day","TN10p","TN90p","TNn","TNx","TX10p","TX90p","TXn","TXx")
seasons <- list(Summer=c(6,7,8),Autumn=c(9,10,11),Winter=c(12,1,2),Spring=c(3,4,5))

##############---spatial plots---##############################################
#Load data
for(ind in 1:length(ETCCDI_index)){
files <- list.files(pattern = ETCCDI_index[ind])
  
for(i in 1:length(files)){
di <- dataInventory(dataset = files[i])
nc <- loadGridData(dataset=files[i],var=names(di))

if(di[[names(di)]][["Units"]]=="m s-1"){
  di[[names(di)]][["Units"]] <- "mm"
  palette=brewer.pal(n=11,name="YlGnBu")
}

if(di[[names(di)]][["Units"]]=="K"){
  palette=rev(brewer.pal(n=11,name="RdYlBu"))
  nc <- gridArithmetics(nc,273,operator = "-")
  di[[names(di)]][["Units"]] <- "ºC"
}

if(di[[names(di)]][["Units"]]=="percentage"){
  palette=rev(brewer.pal(n=11,name="RdYlBu"))
  di[[names(di)]][["Units"]] <- "percentage"
}

###############
data <- list()

if(length(nc$Dates$start<=72)){
  index2 <- redim(climatology(nc),drop=T)
  data[[1]] <- data.frame(Index=as.numeric(index2$Data),
                          Longitude=rep(nc$xyCoords$x,each=length(nc$xyCoords$y)),
                          Latitude=rep(nc$xyCoords$y,length(nc$xyCoords$x)),
                          Season=rep("Annual",length(as.numeric(index2$Data))))
}
if(length(nc$Dates$start)>72){
for(j in 1:length(seasons)){
index2 <- redim(climatology(subsetGrid(nc,season = seasons[[j]])),drop=T)
data[[j+1]] <- data.frame(Index=as.numeric(index2$Data),
                        Longitude=rep(nc$xyCoords$x,each=length(nc$xyCoords$y)),
                        Latitude=rep(nc$xyCoords$y,length(nc$xyCoords$x)),
                       Season=rep(names(seasons)[j],length(as.numeric(index2$Data))))
}}
}

datos <- do.call(rbind,data)
datos$Season <- factor(datos$Season,levels=c("Winter","Autumn","Summer","Spring","Annual"))

png(filename = paste(OUTPUTS,ETCCDI_index[ind],"_IberianPeninsula.png",sep=""),res=300,width=3000,height=1500)
print(ggplot(data=datos,aes(x=Longitude,y=Latitude,fill=Index)) + geom_tile() + facet_wrap(~Season,nrow = 1) +
  borders("world",colour = "black",size=0.2) + scale_x_continuous(n.breaks = 6) + scale_y_continuous(n.breaks = 6) +
  coord_quickmap(xlim = range(datos$Longitude),ylim=range(datos$Latitude),expand = F) + 
  scale_color_gradientn(di[[names(di)]][["Units"]],colours = palette,
                        aesthetics = "fill",na.value = "white") +
  theme_bw() + ggtitle(names(di)) )
dev.off()

png(filename = paste(OUTPUTS,ETCCDI_index[ind],"_Catalunya.png",sep=""),res=300,width=3000,height=1500)
print(ggplot(data=subset(datos,Latitude>40 & Latitude < 43 & Longitude > 0 & Longitude < 3),
            aes(x=Longitude,y=Latitude,fill=Index)) + geom_tile() + facet_wrap(~Season,nrow = 1) +
  borders("world",colour = "black",size=0.2) + scale_x_continuous(n.breaks = 6) + scale_y_continuous(n.breaks = 6) +
  coord_quickmap(ylim = c(40,43),xlim=c(0,3),expand = F) + 
  scale_color_gradientn(di[[names(di)]][["Units"]],colours = palette,
                        aesthetics = "fill",na.value = "white") +
  theme_bw() + ggtitle(names(di)))
dev.off()
}

##############---temporal plots---##############################################
